$!********************************************************************
$! HOTFIX INSTALLER FOR SAS 9.2 HOTFIXES:
$!    NAME:   SAS$ROOT:[INSTALL.ADMIN.HOTFIX.SCRIPT]UPTD_CHKSUM.COM
$!
$! PURPOSE: TO GATHER AND SETUP PARAMETERS NEEDED TO RUN CHECKSUM_UPDATE.PL. 
$!          ALSO SUBMITS THE PERL SCRIPT CHECKSUM_UPDATE.PL.
$!
$!
$!  NOTE:  PRIOR TO SUBMITTING THIS SCRIPT YOU WOULD HAVE
$!         HAD TO FIRST EXTRACT THE HOTFIX.ZIP FROM OUR HOTFIX
$!         DOWNLOAD SITE
$!  
$!  UPDATES TO THIS SCRIPT:
$!         18Nov2008 - Add -vmi to the perl script command to 
$!                     run the checksum_update.pl script. This is
$!                     to allow running the script without having
$!                     to have bash installed.  Also added a statement
$!                     to purge the rules. files.  
$!                      
$!
$!
$! DESCRIPTION OF PARAMETERS NEEDED FOR CHECKSUM_UPDATE.PL:
$!
$!
$!           -hotfix hotfixid     The hotfixid.  If the filelist option is
$!                                not specified, this will be used to derive
$!                                the name of the directives file:
$!                                $SASROOT/9.2/install/admin/hotfix/<HFID>.UPDATES
$!
$!           -sasroot path        The SASROOT path of a current, existing install.
$!                                This is needed in order to locate an up-to-date
$!                                version of the original install checksum files.
$!                                This should be stated down to the version
$!                                (i.e. 9.2).
$!
$!           -filelist file       This will override the default hotfix file
$!                                location.  
$!
$!           -logfile file        This will override the default log file
$!                                location.
$!
$!           -check               This will cause the program parameters to be
$!                                displayed.
$!
$!           -verbose             This will cause information berbose outout to
$!                                be displayed.
$!
$!           -test                This will prevent the actual update to the
$!                                production checksum files.  A message will be
$!                                displayed showing the operations that would
$!                                be performs when not testing.
$!
$!
$!********************************************************************
$!
$! ENVIRONMENT SETTINGS 
$!
$  SET NOVER
$  ON CONTROL_Y THEN GOTO CTRLY_EXIT 
$  WRT == "WRITE SYS$OUTPUT"
$! WHERE ARE WE?
$  CURDIR == F$ENVIRONMENT("DEFAULT")
$! 
$! SETUP A SYMBOL TO REFER TO VMS INTEGRITY
$  EXT == "VI" 
$!
$!  WHERE IS SAS 9.2 INSTALLED? 
$ WRT "EXAMPLE:   DISK:[SAS92.SASFOUNDATION.9^.2]  "
$ WRT " "
$ INQUIRE/NOPUNCT SASROOT "WHAT IS THE FULL PATH OF YOUR SAS92 INSTALLATION? "
$ SASROOT == F$EDIT(SASROOT,"TRIM,UPCASE")
$ WRT " "
$
$!  SETUP PATHS TO THE SAS INSTALL 
$ SASPATH == F$ELEMENT(0, "]", SASROOT)  + "."
$! SHO SYM SASPATH
$ GOSUB HOTFIXID
$! 
$!
$!************************************
$!        SUBROUTINES
$!************************************
$!
$!---------
$ HOTFIXID:
$!---------
$!  GET THE NAME OF HOTFIX CURRENTLY BEING APPLIED
$!  THIS INFORMATION IS IN A FILE CALLED CUR_HTFX.DAT 
$!
$ OPEN/READ CURHFX 'SASPATH'INSTALL.ADMIN.HOTFIX]CUR_HTFX.DAT
$ READ/END=ENDFILE CURHFX HOTFIXID
$! WRT "HERE'S OUR HOTFIXID SYMBOL" 
$! SHO SYM HOTFIXID
$ ENDFILE:
$   CLOSE CURHFX
$   GOSUB CRE_LOGFILE
$ 
$!-------------
$  CRE_LOGFILE:
$!-------------
$!
$ CURDATE == F$EDIT(F$EXTRACT(0,12,F$TIME()),"TRIM") 
$
$  LOGFILE == "''SASPATH'INSTALL.ADMIN.HOTFIX]''HOTFIXID'_''CURDATE'.LOG"
$!  SHO SYM CURDATE
$!  SHO SYM LOGFILE
$! 
$  GOSUB RUN_CHKSUM
$
$!-------------
$   RUN_CHKSUM:
$!-------------
$
$! CREATE CHECKSUM FILES: 
$   PERL  'SASPATH'INSTALL.ADMIN.HOTFIX.SCRIPT]CHECKSUM_UPDATE.PL -
-HOTFIX 'HOTFIXID' -SASROOT 'SASROOT'  -LOG 'LOGFILE' -VMI -VERBOSE 
$ 
$ GOSUB UPDT_HISTFILE
$!
$!
$!--------------
$ UPDT_HISTFILE:                                                                
$!--------------
$! CREATE OR UPDATE THE FILE WITH THE LATEST HOTFIX APPLIED:                    
$!   SAS$ROOT:[INSTALL.ADMIN.HOTFIX]HISTORY_INSTALL_HOTFIX.DAT                         
$!                                                                              
$ CHKFILE = F$SEARCH("SAS$ROOT:[INSTALL.ADMIN.HOTFIX]HISTORY_INSTALL_HOTFIX.DAT")      
$                                                                               
$! DOES THE FILE EXIST? IF NOT CREATE IT:                                       
$ IF CHKFILE .EQS. ""                                                           
$ THEN                                                                          
$    CREATE SAS$ROOT:[INSTALL.ADMIN.HOTFIX]HISTORY_INSTALL_HOTFIX.DAT                  
$    GOTO APPD_UPDT                                                             
$ ELSE                                                                          
$ IF CHKFILE .NES. ""                                                           
$ THEN                                                                          
$    GOSUB APPD_UPDT                                                             
$ ENDIF                                                                         
$ ENDIF                                                                         
$                                                                               
$!----------                                                                    
$ APPD_UPDT:                                                                    
$!----------                                                                    
$ OPEN/APPEND HISTFILE -                                                        
  SAS$ROOT:[INSTALL.ADMIN.HOTFIX]HISTORY_INSTALL_HOTFIX.DAT                            
$ DTTIME = F$TIME()                                                             
$                                                                               
$ WRITE HISTFILE ""                                                             
$ WRITE HISTFILE ""                                                             
$ WRITE HISTFILE "HOTFIX ''HOTFIXID' WAS APPLIED"                                 
$ WRITE HISTFILE "ON THE FOLLOWING DAY:  ''DTTIME'"                             
$ CLOSE HISTFILE                                                                
$!                                                                              
$ GOTO EXIT_RTN                                                                     
$                                                                               
$!-----------                                                                   
$ CTRLY_EXIT:                                                                   
$!-----------                                                                   
$ WRT ""                                                                        
$ WRT "USAGE-I-CTLY, PROCEDURE CANCELED BY CONTROL_Y"                           
$ WRT ""                                                                        
$ SET CONTROL=Y                                                                 
$ GOTO EXIT_RTN           
$!
$!-------------
$   EXIT_RTN  :
$!-------------
$!
$!  CLEANUP
$ PUR/KEEP=2 'SASPATH'INSTALL.ADMIN.HOTFIX]CUR_HTFX.DAT
$ PUR/KEEP=2 'SASPATH'INSTALL.ADMIN.HOTFIX]RULES.
$ PUR/KEEP=2 'SASPATH'INSTALL.ADMIN.HOTFIX.SCRIPT]CHECKSUM_UPDATE.PL
$ PUR/KEEP=2 'SASPATH'INSTALL.ADMIN.HOTFIX.SCRIPT]UPDT_CHKSUM.COM
$!
$  SET DEF 'CURDIR'
$  EXIT
$!
